{% extends "base.html" %}

{% block body %}
    <br><br>
    <ul class="text-left no-bullets" style="display: inline-block; font-size: 18px">
        <li><a href="/elements/">Elements</a></li>
        <li><a href="/disabled-elements/">Disabled Elements</a></li>
        <li><a href="/dynamic-elements/?delay=3">Dynamic Elements</a></li>
        <li><a href="/special-elements/">Special Elements</a></li>
        <li><a href="/drag-and-drop/">Drag and Drop</a></li>
        <li><a href="/form-basic/">Basic form</a></li>
        <li><a href="/ajax-request/">Ajax Request</a></li>
        <li><a href="/tabs/">Tabs and Windows</a></li>
        <li><a href="/frames/">Frames</a></li>
        <li><a href="/iframes/">IFrames</a></li>
        <!--<li><a href="/table-basic/"></a>Table</li>-->
        <!--<li><a href="/table-basic/"></a>Angular</li>-->
        <!--<li><a href="/table-basic/"></a>React</li>-->
        <li><a href="/alert/">Alert</a></li>
        <li><a href="/confirm/">Confirm</a></li>
        <li><a href="/prompt/">Prompt</a></li>
        <li><a href="/confirm-exit/">Confirm exit</a></li>
        <li><a href="/http-error/404/">404 error</a></li>
        <li><a href="/http-error/500/">500 error</a></li>
        <li><a href="/http-error/418/">HTTP error</a> (modify code in the URL)</li>
    </ul>
{% endblock %}