{% from 'component_library.html' import clickable_button %}
<html>
<head>
    <link rel="stylesheet" type="text/css" href="{{url_for('static', filename='css/external/bootstrap.min.css')}}">
    <script src="{{url_for('static', filename='js/external/jquery.min.js')}}"></script>
    <script src="{{url_for('static', filename='js/common.js')}}"></script>
</head>
<body>
<h2>IFrame Bottom Right</h2>
{{ clickable_button('button-bottom-right') }}
</body>
</html>

