{% extends "base.html" %}

{% block title %} - Disabled Elements{% endblock %}

{% block body %}
<h1>Disabled Elements</h1>
<br>
<div class="col-sm-6 offset-sm-3">
    <button class="btn" id="button" disabled>Disabled Button</button>
    <br><br>
    <input type="submit" id="submit" class="btn" value="Disabled Submit" disabled>
    <br><br>
    <input type="text" id="text" class="form-control" value="Disabled Text Input" disabled>
    <br>
    <div>
        <input type="checkbox" id="checkbox" class="form-check-input" disabled>
        <label class="form-check-label" for="checkbox">Disabled Checkbox</label>
    </div>
    <br>
    <div>
        <input id="radiobutton" class="form-check-input" type="radio" name="radiobutton" value="option1" disabled>
        <label class="form-check-label" for="radiobutton">Disabled Radio Button</label>
    </div>
    <br>
    <textarea id="textarea-1" name="textarea-name" class="form-control" rows="4" cols="50" placeholder="disabled textarea" disabled></textarea>
    <br>
    <select id="select" class="form-control" disabled>
        <option value="option-volvo">Volvo</option>
        <option value="option-saab">Saab</option>
        <option value="option-mercedes" selected>Mercedes</option>
        <option value="option-audi">Audi</option>
    </select>
</div>
{% endblock %}