{% from 'component_library.html' import clickable_button %}
<frameset cols="50%,50%">
    <frame src="/frame-bottom-left/" name="frame-bottom-left" id="frameBottomLeft">
    <frame src="/frame-bottom-right/" name="frame-bottom-right" id="frameBottomRight"/>
</frameset>