<head>
    <link rel="stylesheet" type="text/css" href="{{url_for('static', filename='css/external/bootstrap.min.css')}}">
    <link rel="stylesheet" type="text/css" href="{{url_for('static', filename='css/common.css')}}">
    <script src="{{url_for('static', filename='js/external/jquery.min.js')}}"></script>
    <script src="{{url_for('static', filename='js/external/bootstrap.min.js')}}"></script>
    <script src="{{url_for('static', filename='js/common.js')}}"></script>
</head>
<frameset rows="50%,50%">
    <frame src="/frame-top/" name="frame-top" id="frameTop">
    <frame src="/frame-bottom/" name="frame-bottom" id="frameBottom">
</frameset>
